==> django-hotsauce-0.5.1.tar.gz: django-hotsauce-0.5.1/examples/webdav/demo.py <==
#!/usr/bin/env python
from wsgiref.simple_server import make_server

from webdav.controller import DAVRequestHandler

from pywebdav.lib.INI_Parse import Configuration
from pywebdav.server.fshandler import FilesystemHandler
from pywebdav.server.daemonize import runserver

import logging
#stripped down WSGI controller
#wsgi_app = DAV10Controller

from logging_conf import syslogHandler 
log = logging.getLogger('pywebdav')
log.addHandler(syslogHandler)
log.setLevel(logging.DEBUG)

def gethandler(handler_class, directory, host, port, configfile=None, verbose=True):
    """Prepare and return a DAV 1.0 request handler"""
    # setup the configuration obj (required)
    if configfile is not None:
        setattr(handler_class, '_config', Configuration(configfile))

    # dispatch directory and host to the filesystem handler
    # This handler is responsible from where to take the data
    setattr(handler_class, 'IFACE_CLASS', \
        FilesystemHandler(directory, 'http://%s:%s/' % (host, port), verbose))

    return handler_class

if __name__ == '__main__':
    directory = '/home/research'
    host = 'localhost'
    port = 8081
    dav10handler = gethandler(
        DAVRequestHandler, directory, host, port,
        configfile='webdav.conf')
    #import pdb; pdb.set_trace()
    #s = make_server(host, port, wsgi_app, \
    #    handler_class=davhandler)
    s = runserver(
        verbose=True, 
        directory=directory, 
        host=host, 
        port=port,
        user='test', 
        password='test00', 
        handler=dav10handler
    )
    s.serve_forever()

==> django-hotsauce-0.5.3.tar.gz: django-hotsauce-0.5.3/examples/webdav/demo.py <==
#!/usr/bin/env python
from wsgiref.simple_server import make_server

from webdav.controller import DAVRequestHandler

from pywebdav.lib.INI_Parse import Configuration
from pywebdav.server.fshandler import FilesystemHandler
from pywebdav.server.server import runserver

import logging
#stripped down WSGI controller
#wsgi_app = DAV10Controller

from logging_conf import syslogHandler 
log = logging.getLogger('pywebdav')
log.addHandler(syslogHandler)
log.setLevel(logging.DEBUG)

def gethandler(handler_class, directory, host, port, configfile=None, verbose=True):
    """Prepare and return a DAV 1.0 request handler"""
    # setup the configuration obj (required)
    if configfile is not None:
        setattr(handler_class, '_config', Configuration(configfile))

    # dispatch directory and host to the filesystem handler
    # This handler is responsible from where to take the data
    setattr(handler_class, 'IFACE_CLASS', \
        FilesystemHandler(directory, 'http://%s:%s/' % (host, port), verbose))

    return handler_class

if __name__ == '__main__':
    directory = '/home/research'
    host = 'localhost'
    port = 8081
    dav10handler = gethandler(
        DAVRequestHandler, directory, host, port,
        configfile='webdav.conf')
    #import pdb; pdb.set_trace()
    #s = make_server(host, port, wsgi_app, \
    #    handler_class=davhandler)
    s = runserver(
        verbose=True, 
        directory=directory, 
        host=host, 
        port=port,
        user='test', 
        password='test00', 
        handler=dav10handler
    )
    s.serve_forever()
